<a id="types-aiobotocore-guardduty"></a>

# types-aiobotocore-guardduty

[![PyPI - types-aiobotocore-guardduty](https://img.shields.io/pypi/v/types-aiobotocore-guardduty.svg?color=blue)](https://pypi.org/project/types-aiobotocore-guardduty)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-guardduty.svg?color=blue)](https://pypi.org/project/types-aiobotocore-guardduty)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-guardduty?color=blue)](https://pypistats.org/packages/types-aiobotocore-guardduty)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.GuardDuty 2.5.0](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/guardduty.html#GuardDuty)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.12.5](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-guardduty docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_guardduty/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-guardduty](#types-aiobotocore-guardduty)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `GuardDuty` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[guardduty]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[guardduty]'


# standalone installation
python -m pip install types-aiobotocore-guardduty
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-guardduty
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[guardduty]` in your environment:

```bash
python -m pip install 'types-aiobotocore[guardduty]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[guardduty]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[guardduty]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[guardduty]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[guardduty]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[guardduty]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[guardduty]` in your environment:

```bash
python -m pip install 'types-aiobotocore[guardduty]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[guardduty]` in your environment:

```bash
python -m pip install 'types-aiobotocore[guardduty]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`GuardDutyClient` provides annotations for
`session.create_client("guardduty")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_guardduty import GuardDutyClient

session = get_session()
async with session.create_client("guardduty") as client:
    client: GuardDutyClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_guardduty.paginator` module contains type annotations for
all paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_guardduty import GuardDutyClient
from types_aiobotocore_guardduty.paginator import (
    DescribeMalwareScansPaginator,
    ListDetectorsPaginator,
    ListFiltersPaginator,
    ListFindingsPaginator,
    ListIPSetsPaginator,
    ListInvitationsPaginator,
    ListMembersPaginator,
    ListOrganizationAdminAccountsPaginator,
    ListThreatIntelSetsPaginator,
)

session = get_session()
async with session.create_client("guardduty") as client:
    client: GuardDutyClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_malware_scans_paginator: DescribeMalwareScansPaginator = client.get_paginator(
        "describe_malware_scans"
    )
    list_detectors_paginator: ListDetectorsPaginator = client.get_paginator("list_detectors")
    list_filters_paginator: ListFiltersPaginator = client.get_paginator("list_filters")
    list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
    list_ip_sets_paginator: ListIPSetsPaginator = client.get_paginator("list_ip_sets")
    list_invitations_paginator: ListInvitationsPaginator = client.get_paginator("list_invitations")
    list_members_paginator: ListMembersPaginator = client.get_paginator("list_members")
    list_organization_admin_accounts_paginator: ListOrganizationAdminAccountsPaginator = (
        client.get_paginator("list_organization_admin_accounts")
    )
    list_threat_intel_sets_paginator: ListThreatIntelSetsPaginator = client.get_paginator(
        "list_threat_intel_sets"
    )
```

<a id="literals"></a>

### Literals

`types_aiobotocore_guardduty.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_guardduty.literals import (
    AdminStatusType,
    CriterionKeyType,
    DataSourceStatusType,
    DataSourceType,
    DescribeMalwareScansPaginatorName,
    DestinationTypeType,
    DetectorStatusType,
    EbsSnapshotPreservationType,
    FeedbackType,
    FilterActionType,
    FindingPublishingFrequencyType,
    FindingStatisticTypeType,
    IpSetFormatType,
    IpSetStatusType,
    ListDetectorsPaginatorName,
    ListFiltersPaginatorName,
    ListFindingsPaginatorName,
    ListIPSetsPaginatorName,
    ListInvitationsPaginatorName,
    ListMembersPaginatorName,
    ListOrganizationAdminAccountsPaginatorName,
    ListThreatIntelSetsPaginatorName,
    OrderByType,
    PublishingStatusType,
    ScanCriterionKeyType,
    ScanResultType,
    ScanStatusType,
    ThreatIntelSetFormatType,
    ThreatIntelSetStatusType,
    UsageStatisticTypeType,
    GuardDutyServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AdminStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_guardduty.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_guardduty.type_defs import (
    AcceptAdministratorInvitationRequestRequestTypeDef,
    AcceptInvitationRequestRequestTypeDef,
    AccessControlListTypeDef,
    AccessKeyDetailsTypeDef,
    AccountDetailTypeDef,
    BlockPublicAccessTypeDef,
    DnsRequestActionTypeDef,
    AdminAccountTypeDef,
    AdministratorTypeDef,
    ArchiveFindingsRequestRequestTypeDef,
    DomainDetailsTypeDef,
    RemoteAccountDetailsTypeDef,
    BucketPolicyTypeDef,
    CityTypeDef,
    CloudTrailConfigurationResultTypeDef,
    ConditionTypeDef,
    SecurityContextTypeDef,
    VolumeMountTypeDef,
    CountryTypeDef,
    ResponseMetadataTypeDef,
    CreateIPSetRequestRequestTypeDef,
    UnprocessedAccountTypeDef,
    DestinationPropertiesTypeDef,
    CreateSampleFindingsRequestRequestTypeDef,
    CreateThreatIntelSetRequestRequestTypeDef,
    DNSLogsConfigurationResultTypeDef,
    FlowLogsConfigurationResultTypeDef,
    S3LogsConfigurationResultTypeDef,
    S3LogsConfigurationTypeDef,
    DataSourceFreeTrialTypeDef,
    DeclineInvitationsRequestRequestTypeDef,
    DefaultServerSideEncryptionTypeDef,
    DeleteDetectorRequestRequestTypeDef,
    DeleteFilterRequestRequestTypeDef,
    DeleteIPSetRequestRequestTypeDef,
    DeleteInvitationsRequestRequestTypeDef,
    DeleteMembersRequestRequestTypeDef,
    DeletePublishingDestinationRequestRequestTypeDef,
    DeleteThreatIntelSetRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    SortCriteriaTypeDef,
    DescribeOrganizationConfigurationRequestRequestTypeDef,
    DescribePublishingDestinationRequestRequestTypeDef,
    DestinationTypeDef,
    DisableOrganizationAdminAccountRequestRequestTypeDef,
    DisassociateFromAdministratorAccountRequestRequestTypeDef,
    DisassociateFromMasterAccountRequestRequestTypeDef,
    DisassociateMembersRequestRequestTypeDef,
    VolumeDetailTypeDef,
    EbsVolumesResultTypeDef,
    TagTypeDef,
    EnableOrganizationAdminAccountRequestRequestTypeDef,
    ThreatIntelligenceDetailTypeDef,
    FilterConditionTypeDef,
    FindingStatisticsTypeDef,
    GeoLocationTypeDef,
    GetAdministratorAccountRequestRequestTypeDef,
    GetDetectorRequestRequestTypeDef,
    GetFilterRequestRequestTypeDef,
    GetIPSetRequestRequestTypeDef,
    GetMalwareScanSettingsRequestRequestTypeDef,
    GetMasterAccountRequestRequestTypeDef,
    MasterTypeDef,
    GetMemberDetectorsRequestRequestTypeDef,
    GetMembersRequestRequestTypeDef,
    MemberTypeDef,
    GetRemainingFreeTrialDaysRequestRequestTypeDef,
    GetThreatIntelSetRequestRequestTypeDef,
    UsageCriteriaTypeDef,
    HighestSeverityThreatDetailsTypeDef,
    HostPathTypeDef,
    IamInstanceProfileTypeDef,
    ProductCodeTypeDef,
    InvitationTypeDef,
    InviteMembersRequestRequestTypeDef,
    KubernetesAuditLogsConfigurationResultTypeDef,
    KubernetesAuditLogsConfigurationTypeDef,
    KubernetesUserDetailsTypeDef,
    ListDetectorsRequestRequestTypeDef,
    ListFiltersRequestRequestTypeDef,
    ListIPSetsRequestRequestTypeDef,
    ListInvitationsRequestRequestTypeDef,
    ListMembersRequestRequestTypeDef,
    ListOrganizationAdminAccountsRequestRequestTypeDef,
    ListPublishingDestinationsRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListThreatIntelSetsRequestRequestTypeDef,
    LocalIpDetailsTypeDef,
    LocalPortDetailsTypeDef,
    ScanEc2InstanceWithFindingsTypeDef,
    RemotePortDetailsTypeDef,
    PrivateIpAddressDetailsTypeDef,
    SecurityGroupTypeDef,
    OrganizationS3LogsConfigurationResultTypeDef,
    OrganizationS3LogsConfigurationTypeDef,
    OrganizationEbsVolumesResultTypeDef,
    OrganizationEbsVolumesTypeDef,
    OrganizationKubernetesAuditLogsConfigurationResultTypeDef,
    OrganizationKubernetesAuditLogsConfigurationTypeDef,
    OrganizationTypeDef,
    OwnerTypeDef,
    ResourceDetailsTypeDef,
    ScanConditionPairTypeDef,
    ScannedItemCountTypeDef,
    ThreatsDetectedItemCountTypeDef,
    ScanFilePathTypeDef,
    ScanResultDetailsTypeDef,
    TriggerDetailsTypeDef,
    ServiceAdditionalInfoTypeDef,
    StartMonitoringMembersRequestRequestTypeDef,
    StopMonitoringMembersRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    TotalTypeDef,
    UnarchiveFindingsRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateFindingsFeedbackRequestRequestTypeDef,
    UpdateIPSetRequestRequestTypeDef,
    UpdateThreatIntelSetRequestRequestTypeDef,
    CreateMembersRequestRequestTypeDef,
    AccountLevelPermissionsTypeDef,
    BucketLevelPermissionsTypeDef,
    FindingCriteriaTypeDef,
    ContainerTypeDef,
    CreateFilterResponseTypeDef,
    CreateIPSetResponseTypeDef,
    CreatePublishingDestinationResponseTypeDef,
    CreateThreatIntelSetResponseTypeDef,
    GetAdministratorAccountResponseTypeDef,
    GetIPSetResponseTypeDef,
    GetInvitationsCountResponseTypeDef,
    GetThreatIntelSetResponseTypeDef,
    ListDetectorsResponseTypeDef,
    ListFiltersResponseTypeDef,
    ListFindingsResponseTypeDef,
    ListIPSetsResponseTypeDef,
    ListOrganizationAdminAccountsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListThreatIntelSetsResponseTypeDef,
    UpdateFilterResponseTypeDef,
    CreateMembersResponseTypeDef,
    DeclineInvitationsResponseTypeDef,
    DeleteInvitationsResponseTypeDef,
    DeleteMembersResponseTypeDef,
    DisassociateMembersResponseTypeDef,
    InviteMembersResponseTypeDef,
    StartMonitoringMembersResponseTypeDef,
    StopMonitoringMembersResponseTypeDef,
    UpdateMemberDetectorsResponseTypeDef,
    CreatePublishingDestinationRequestRequestTypeDef,
    DescribePublishingDestinationResponseTypeDef,
    UpdatePublishingDestinationRequestRequestTypeDef,
    KubernetesDataSourceFreeTrialTypeDef,
    MalwareProtectionDataSourceFreeTrialTypeDef,
    ListDetectorsRequestListDetectorsPaginateTypeDef,
    ListFiltersRequestListFiltersPaginateTypeDef,
    ListIPSetsRequestListIPSetsPaginateTypeDef,
    ListInvitationsRequestListInvitationsPaginateTypeDef,
    ListMembersRequestListMembersPaginateTypeDef,
    ListOrganizationAdminAccountsRequestListOrganizationAdminAccountsPaginateTypeDef,
    ListThreatIntelSetsRequestListThreatIntelSetsPaginateTypeDef,
    GetFindingsRequestRequestTypeDef,
    ListPublishingDestinationsResponseTypeDef,
    EbsVolumeDetailsTypeDef,
    ScanEc2InstanceWithFindingsResultTypeDef,
    EksClusterDetailsTypeDef,
    EvidenceTypeDef,
    FilterCriterionTypeDef,
    GetFindingsStatisticsResponseTypeDef,
    GetMasterAccountResponseTypeDef,
    GetMembersResponseTypeDef,
    ListMembersResponseTypeDef,
    GetUsageStatisticsRequestRequestTypeDef,
    VolumeTypeDef,
    ListInvitationsResponseTypeDef,
    KubernetesConfigurationResultTypeDef,
    KubernetesConfigurationTypeDef,
    MalwareProtectionConfigurationTypeDef,
    NetworkInterfaceTypeDef,
    OrganizationScanEc2InstanceWithFindingsResultTypeDef,
    OrganizationScanEc2InstanceWithFindingsTypeDef,
    OrganizationKubernetesConfigurationResultTypeDef,
    OrganizationKubernetesConfigurationTypeDef,
    RemoteIpDetailsTypeDef,
    ScanConditionTypeDef,
    ScanThreatNameTypeDef,
    ScanTypeDef,
    UsageAccountResultTypeDef,
    UsageDataSourceResultTypeDef,
    UsageResourceResultTypeDef,
    PermissionConfigurationTypeDef,
    CreateFilterRequestRequestTypeDef,
    GetFilterResponseTypeDef,
    GetFindingsStatisticsRequestRequestTypeDef,
    ListFindingsRequestListFindingsPaginateTypeDef,
    ListFindingsRequestRequestTypeDef,
    UpdateFilterRequestRequestTypeDef,
    DataSourcesFreeTrialTypeDef,
    MalwareProtectionConfigurationResultTypeDef,
    FilterCriteriaTypeDef,
    EcsTaskDetailsTypeDef,
    KubernetesWorkloadDetailsTypeDef,
    DataSourceConfigurationsTypeDef,
    InstanceDetailsTypeDef,
    OrganizationMalwareProtectionConfigurationResultTypeDef,
    OrganizationMalwareProtectionConfigurationTypeDef,
    AwsApiCallActionTypeDef,
    KubernetesApiCallActionTypeDef,
    NetworkConnectionActionTypeDef,
    PortProbeDetailTypeDef,
    ScanResourceCriteriaTypeDef,
    ThreatDetectedByNameTypeDef,
    DescribeMalwareScansResponseTypeDef,
    UsageStatisticsTypeDef,
    PublicAccessTypeDef,
    AccountFreeTrialInfoTypeDef,
    DataSourceConfigurationsResultTypeDef,
    UnprocessedDataSourcesResultTypeDef,
    DescribeMalwareScansRequestDescribeMalwareScansPaginateTypeDef,
    DescribeMalwareScansRequestRequestTypeDef,
    EcsClusterDetailsTypeDef,
    KubernetesDetailsTypeDef,
    CreateDetectorRequestRequestTypeDef,
    UpdateDetectorRequestRequestTypeDef,
    UpdateMemberDetectorsRequestRequestTypeDef,
    OrganizationDataSourceConfigurationsResultTypeDef,
    OrganizationDataSourceConfigurationsTypeDef,
    PortProbeActionTypeDef,
    GetMalwareScanSettingsResponseTypeDef,
    UpdateMalwareScanSettingsRequestRequestTypeDef,
    ScanDetectionsTypeDef,
    GetUsageStatisticsResponseTypeDef,
    S3BucketDetailTypeDef,
    GetRemainingFreeTrialDaysResponseTypeDef,
    GetDetectorResponseTypeDef,
    MemberDataSourceConfigurationTypeDef,
    CreateDetectorResponseTypeDef,
    DescribeOrganizationConfigurationResponseTypeDef,
    UpdateOrganizationConfigurationRequestRequestTypeDef,
    ActionTypeDef,
    EbsVolumeScanDetailsTypeDef,
    ResourceTypeDef,
    GetMemberDetectorsResponseTypeDef,
    ServiceTypeDef,
    FindingTypeDef,
    GetFindingsResponseTypeDef,
)


def get_structure() -> AcceptAdministratorInvitationRequestRequestTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-guardduty` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_guardduty/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
